@@ -1,11 +1,11 @@
 #' NMRphasing
 #' @description Phase error correction wrap up function
-#' @details This is a wrap function to process phase error correction and baseline correction with nine different choices.
+#' @details This is a wrap function to process phase error correction and baseline correction with eleven different choices.
 #' @param specDatIn Input spectrum data, which can be one of the four formats:
 #'                a vector of absorption spectrum; a complex vector; a data matrix or a data frame with two columns of spectrum data,
 #'                which 1st column is for absorption spectrum, and 2nd column is for dispersion spectrum
 #' @param absorptionOnly A logical variable to tell us if specDatIn is a a vector of absorption specrtrum, default is false
-#' @param method One of phase correction and baseline correction methods. There are nine available choices, which are "NLS", "MPC_DAOM", "MPC_EMP", "MPC_AAM", "MPC_DSM", "SPC_DAOM", "SPC_EMP", "SPC_AAM", "SPC_DSM",
+#' @param method One of phase correction and baseline correction methods. There are eleven available choices, which are "NLS", "MPC_DAOM", "MPC_EMP", "MPC_AAM", "MPC_DSM", "MPC_ADSM", "SPC_DAOM", "SPC_EMP", "SPC_AAM", "SPC_DSM", "SPC_ADSM",
 #'               with "NLS", non-linear shrinkage as default.
 #' @param withBC A logical parameter that enables/disables baseline correction after baseline correction
 #' @return A numeric vector of phase corrected absorption spectrum
@@ -13,6 +13,8 @@
 #' @author Aixiang Jiang
 #' @references
 
+#' Jiang, A. (2024). Phase Error Correction in Magnetic Resonance: A Review of Models, Optimization Functions, and Optimizers in Traditional Statistics and Neural Networks. Preprints. https://doi.org/10.20944/preprints202409.2252.v1
+#'
 #' Binczyk F, Tarnawski R, Polanska J (2015) Strategies for optimizing the phase correction algorithms in Nuclear Magnetic Resonance spectroscopy. Biomed Eng Online 14 Suppl 2:S5.
 #'
 #' Chen L, Weng Z, Goh L, Garland M (2002) An efficient algorithm for automatic phase correction of NMR spectra based on entropy minimization. J Magn Reson 158:164–168.
@@ -35,7 +37,8 @@
 
 
 NMRphasing = function (specDatIn, absorptionOnly = FALSE,
-                       method = c("NLS", "MPC_DANM", "MPC_EMP","MPC_AAM", "MPC_DSM","SPC_DANM", "SPC_EMP", "SPC_AAM", "SPC_DSM"),
+                       method = c("NLS", "MPC_DANM", "MPC_EMP","MPC_AAM", "MPC_DSM","MPC_ADSM",
+                                  "SPC_DANM", "SPC_EMP", "SPC_AAM", "SPC_DSM", "SPC_ADSM"),
                        withBC = TRUE){
   datin = NA
   if(absorptionOnly){
@@ -56,6 +59,8 @@ NMRphasing = function (specDatIn, absorptionOnly = FALSE,
     outdat = MPC_AAM(specdat = datin, withBC = withBC)
   }else if(method == "MPC_DSM"){
     outdat = MPC_DSM(specdat = datin, withBC = withBC)
+  }else if(method == "MPC_ADSM"){
+    outdat = MPC_ADSM(specdat = datin, withBC = withBC)
   }else if(method == "SPC_DANM"){
      outdat = SPC_DANM(specdat = datin, withBC = withBC)
   }else if(method == "SPC_EMP"){
@@ -64,6 +69,8 @@ NMRphasing = function (specDatIn, absorptionOnly = FALSE,
      outdat = SPC_AAM(specdat = datin, withBC = withBC)
   }else if(method == "SPC_DSM"){
      outdat = SPC_DSM(specdat = datin, withBC = withBC)
+  }else if(method == "SPC_ADSM"){
+    outdat = SPC_ADSM(specdat = datin, withBC = withBC)
   }else{  ## default is NLS
      outdat = NLS(specdat = datin, withBC = withBC)
   }
